deepsport_utilities API documentation

# Package `deepsport_utilities`

Expand source code

    from deepsport_utilities.ds.generic_dataset import import_dataset, export_dataset, GenericItem, serialize_keys, deserialize_keys
    from deepsport_utilities.ds.instants_dataset import InstantsDataset
    from deepsport_utilities.court import Court
    from deepsport_utilities.dataset import find, Subset, SubsetType

## Sub-modules

`deepsport_utilities.calib`
`deepsport_utilities.court`
`deepsport_utilities.dataset`
`deepsport_utilities.ds`
`deepsport_utilities.transforms`
`deepsport_utilities.utils`